==> apache-asterixdb-0.9.4-source-release.zip: apache-asterixdb-0.9.4/asterix-om/src/main/java/org/apache/asterix/object/base/AdmBooleanNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.object.base;

import org.apache.asterix.om.types.ATypeTag;

public class AdmBooleanNode implements IAdmNode {

    public static final AdmBooleanNode TRUE = new AdmBooleanNode(true);
    public static final AdmBooleanNode FALSE = new AdmBooleanNode(false);
    private final boolean value;

    private AdmBooleanNode(boolean value) {
        this.value = value;
    }

    @Override
    public ATypeTag getType() {
        return ATypeTag.BOOLEAN;
    }

    public boolean get() {
        return value;
    }

    @Override
    public void reset() {
        // Nothing to do
    }

    public static AdmBooleanNode get(boolean value) {
        return value ? TRUE : FALSE;
    }

    public static AdmBooleanNode get(Boolean value) {
        return value.booleanValue() ? TRUE : FALSE;
    }

    @Override
    public String toString() {
        return Boolean.toString(value);
    }
}

==> apache-asterixdb-0.9.9-source-release.zip: apache-asterixdb-0.9.9/asterix-om/src/main/java/org/apache/asterix/object/base/AdmBooleanNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.object.base;

import java.io.DataOutput;
import java.io.IOException;

import org.apache.asterix.om.types.ATypeTag;

public class AdmBooleanNode implements IAdmNode {

    private static final long serialVersionUID = 1L;
    public static final AdmBooleanNode TRUE = new AdmBooleanNode(true);
    public static final AdmBooleanNode FALSE = new AdmBooleanNode(false);
    private final boolean value;

    private AdmBooleanNode(boolean value) {
        this.value = value;
    }

    @Override
    public ATypeTag getType() {
        return ATypeTag.BOOLEAN;
    }

    public boolean get() {
        return value;
    }

    @Override
    public void reset() {
        // Nothing to do
    }

    public static AdmBooleanNode get(boolean value) {
        return value ? TRUE : FALSE;
    }

    public static AdmBooleanNode get(Boolean value) {
        return value.booleanValue() ? TRUE : FALSE;
    }

    @Override
    public String toString() {
        return Boolean.toString(value);
    }

    @Override
    public void serializeValue(DataOutput dataOutput) throws IOException {
        dataOutput.writeBoolean(value);
    }
}
